==> piwigo-2.3.1.zip: piwigo/language/af_ZA/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Average rate'] = "Gemiddelde gradering";
$lang['Rate'] = "Gradeer";
$lang['Access type'] = 'Toegangstipe';
$lang['ACCESS_0'] = 'Vry toegang';
$lang['ACCESS_1'] = 'Toegang tot alles';
$lang['ACCESS_2'] = 'Toegang aan geregistreerde gebruikers';
$lang['ACCESS_3'] = 'Toegang aan administrateurs';
$lang['ACCESS_4'] = 'Toegang aan webmeesters';
$lang['ACCESS_5'] = 'Geen toegang';

$lang[' and %d virtual'] = 'en %d virtuele';
$lang['%d album including'] = '%d album ingesluit';
$lang['%d album moved'] = '%d album geskuif';
$lang['%d albums including'] = '%d albums insluitend';
$lang['%d albums moved'] = '%d albums geskuif';
$lang['%d anomalies have been detected corrected.'] = '%d onreëlmatighede is gevind en reggemaak';
$lang['%d anomalies have been detected.'] = '%d onreëlmatighede is gevind';
$lang['%d anomalies have been ignored.'] = '%d onreëlmatighede is geignoreer';
$lang['%d anomalies have not been corrected.'] = '%d onreëlmatighede is nie reggemaak nie';
$lang['%d anomaly has been corrected.'] = '%d onreëlmatigheid is reggemaak';
$lang['%d anomaly has been detected.'] = '%d onreëlmatigheid is gevind';
$lang['%d anomaly has been ignored.'] = '%d onreëlmatigheid is geignoreer';
$lang['%d anomaly has not been corrected.'] = '%d onreëlmatigheid is nie reggemaak nie';
$lang['%d association'] = '%d assosiasie';
$lang['%d associations'] = '%d assosiasies';
$lang['%d group'] = '%d groep';
$lang['%d groups'] = '%d groepe';
$lang['%d guest'] = '%d gas';
$lang['%d guests'] = '%d gaste';
$lang['%d line filtered'] = '%d lyn gefilter';
$lang['%d lines filtered'] = '%d lyne gefilter';
$lang['%d mail was not sent.'] = '%d epos is nie gestuur nie';
$lang['%d mail was sent.'] = '%d epos is gestuur';
$lang['%d mails were not sent.'] = '%d eposse is nie gestuur nie';
$lang['%d mails were sent.'] = '%d eposse is gestuur';
$lang['%d member'] = '%d lid';
$lang['%d members'] = '%d lede';
$lang['%d of %d photos selected'] = '%d van %d fotos gekies';
$lang['%d parameter was updated.'] = '%d parameter is opgedateer';
$lang['%d parameters were updated.'] = '%d parameters is opgedateer';
$lang['%d photo was deleted'] = '%d foto is verwyder';
$lang['%d photos uploaded'] = '@d fotos opgelaai';
$lang['%d photos were deleted'] = '@d fotos verwyder';
$lang['%d physical'] = '@d fisies';
$lang['%d tag'] = '@d etiket';
$lang['%d tags'] = '@d etikette';
$lang['%d user'] = '%d gebruiker ';
$lang['%d user comment rejected'] = '@d gebruikerskommentaar verwerp';
$lang['%d user comment validated'] = '@d gebruikerskommentaar aanvaar';
$lang['%d user comments rejected'] = '@d gebruikerskommentare verwerp ';
$lang['%d user comments validated'] = '@d gebruikerskommentare aanvaar';
$lang['%d user deleted'] = '@d gebruikers verwyder';
$lang['%d user was not updated.'] = '%d gebruiker is nie opgedateer nie';
$lang['%d user was updated.'] = '%d gebruikers is opgedateer ';
$lang['%d users'] = '%d gebruikers ';
$lang['%d users deleted'] = '%d gebruikers verwyder ';
$lang['%d users were not updated.'] = '%d gebruikers is nie opgedateer nie';
$lang['%d users were updated.'] = '%d gebruikers is opgedateer ';
$lang['%d waiting for validation'] = '%d wag vir bekragtiging';
$lang['%s has been successfully upgraded.'] = '%s is suksesvol opgegradeer';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s moet as "false" gemerk word in jou local/config/config.inc.php lêer';
$lang['%s value is not correct file because exif are not supported'] = '%s waarde is nie regte lêer nie want exif word nie ondersteun nie';
$lang['+ Add an upload box'] = '+ Voeg oplaai vakkie by';
$lang[', click on'] = ', kliek op';
$lang['A local listing.xml file has been found for'] = '\'n Plaaslike listing.xml lêer is gevind';
$lang['A new version of Piwigo is available.'] = '\'n Nuwe weergawe van Piwigo is beskikbaar.';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = '\'n beeld lêertipe benodig \'n duimnael. Die duimnael moet in die ondergids "thumbnail" van die album gids wees. Die duimnael lêernaam moet begin met die opgestelde duimnael voorvoegsel en die uitbreiding moet een van die volgende lys wees:';
$lang['Action'] = 'Aksie';
$lang['Actions'] = 'Aksies';
$lang['Activate'] = 'Aktiveer ';
$lang['Activate field "%s"'] = 'Aktiveer veld "%s"';
$lang['Activate icon "%s"'] = 'Aktiveer ikoon "%s"';
$lang['Activate icon "new" next to albums and pictures'] = 'Aktiveer ikoon "nuut" langs albums en prentjies';
$lang['Activate Navigation Bar'] = 'Aktiveer Navigasie Staaf';
$lang['Activate Navigation Thumbnails'] = 'Aktiveer Navigasie Duimnaels';
$lang['Active Languages'] = 'Aktiveer Tale';
$lang['Active Plugins'] = 'Aktiveer Invoegsels';
$lang['Active Themes'] = 'Aktiveer Temas';
?>

==> piwigo-2.3.4.zip: piwigo/language/af_ZA/admin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Average rate'] = "Gemiddelde gradering";
$lang['Rate'] = "Gradeer";
$lang['Access type'] = 'Toegangstipe';
$lang['ACCESS_0'] = 'Vry toegang';
$lang['ACCESS_1'] = 'Toegang tot alles';
$lang['ACCESS_2'] = 'Toegang aan geregistreerde gebruikers';
$lang['ACCESS_3'] = 'Toegang aan administrateurs';
$lang['ACCESS_4'] = 'Toegang aan webmeesters';
$lang['ACCESS_5'] = 'Geen toegang';

$lang[' and %d virtual'] = 'en %d virtuele';
$lang['%d album including'] = '%d album ingesluit';
$lang['%d album moved'] = '%d album geskuif';
$lang['%d albums including'] = '%d albums insluitend';
$lang['%d albums moved'] = '%d albums geskuif';
$lang['%d anomalies have been detected corrected.'] = '%d onreëlmatighede is gevind en reggemaak';
$lang['%d anomalies have been detected.'] = '%d onreëlmatighede is gevind';
$lang['%d anomalies have been ignored.'] = '%d onreëlmatighede is geignoreer';
$lang['%d anomalies have not been corrected.'] = '%d onreëlmatighede is nie reggemaak nie';
$lang['%d anomaly has been corrected.'] = '%d onreëlmatigheid is reggemaak';
$lang['%d anomaly has been detected.'] = '%d onreëlmatigheid is gevind';
$lang['%d anomaly has been ignored.'] = '%d onreëlmatigheid is geignoreer';
$lang['%d anomaly has not been corrected.'] = '%d onreëlmatigheid is nie reggemaak nie';
$lang['%d association'] = '%d assosiasie';
$lang['%d associations'] = '%d assosiasies';
$lang['%d group'] = '%d groep';
$lang['%d groups'] = '%d groepe';
$lang['%d guest'] = '%d gas';
$lang['%d guests'] = '%d gaste';
$lang['%d line filtered'] = '%d lyn gefilter';
$lang['%d lines filtered'] = '%d lyne gefilter';
$lang['%d mail was not sent.'] = '%d epos is nie gestuur nie';
$lang['%d mail was sent.'] = '%d epos is gestuur';
$lang['%d mails were not sent.'] = '%d eposse is nie gestuur nie';
$lang['%d mails were sent.'] = '%d eposse is gestuur';
$lang['%d member'] = '%d lid';
$lang['%d members'] = '%d lede';
$lang['%d of %d photos selected'] = '%d van %d fotos gekies';
$lang['%d parameter was updated.'] = '%d parameter is opgedateer';
$lang['%d parameters were updated.'] = '%d parameters is opgedateer';
$lang['%d photo was deleted'] = '%d foto is verwyder';
$lang['%d photos uploaded'] = '@d fotos opgelaai';
$lang['%d photos were deleted'] = '@d fotos verwyder';
$lang['%d physical'] = '@d fisies';
$lang['%d tag'] = '@d etiket';
$lang['%d tags'] = '@d etikette';
$lang['%d user'] = '%d gebruiker ';
$lang['%d user comment rejected'] = '@d gebruikerskommentaar verwerp';
$lang['%d user comment validated'] = '@d gebruikerskommentaar aanvaar';
$lang['%d user comments rejected'] = '@d gebruikerskommentare verwerp ';
$lang['%d user comments validated'] = '@d gebruikerskommentare aanvaar';
$lang['%d user deleted'] = '@d gebruikers verwyder';
$lang['%d user was not updated.'] = '%d gebruiker is nie opgedateer nie';
$lang['%d user was updated.'] = '%d gebruikers is opgedateer ';
$lang['%d users'] = '%d gebruikers ';
$lang['%d users deleted'] = '%d gebruikers verwyder ';
$lang['%d users were not updated.'] = '%d gebruikers is nie opgedateer nie';
$lang['%d users were updated.'] = '%d gebruikers is opgedateer ';
$lang['%d waiting for validation'] = '%d wag vir bekragtiging';
$lang['%s has been successfully upgraded.'] = '%s is suksesvol opgegradeer';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s moet as "false" gemerk word in jou local/config/config.inc.php lêer';
$lang['%s value is not correct file because exif are not supported'] = '%s waarde is nie regte lêer nie want exif word nie ondersteun nie';
$lang['+ Add an upload box'] = '+ Voeg oplaai vakkie by';
$lang[', click on'] = ', kliek op';
$lang['A local listing.xml file has been found for'] = '\'n Plaaslike listing.xml lêer is gevind';
$lang['A new version of Piwigo is available.'] = '\'n Nuwe weergawe van Piwigo is beskikbaar.';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = '\'n beeld lêertipe benodig \'n duimnael. Die duimnael moet in die ondergids "thumbnail" van die album gids wees. Die duimnael lêernaam moet begin met die opgestelde duimnael voorvoegsel en die uitbreiding moet een van die volgende lys wees:';
$lang['Action'] = 'Aksie';
$lang['Actions'] = 'Aksies';
$lang['Activate'] = 'Aktiveer ';
$lang['Activate field "%s"'] = 'Aktiveer veld "%s"';
$lang['Activate icon "%s"'] = 'Aktiveer ikoon "%s"';
$lang['Activate icon "new" next to albums and pictures'] = 'Aktiveer ikoon "nuut" langs albums en prentjies';
$lang['Activate Navigation Bar'] = 'Aktiveer Navigasie Staaf';
$lang['Activate Navigation Thumbnails'] = 'Aktiveer Navigasie Duimnaels';
$lang['Active Languages'] = 'Aktiveer Tale';
$lang['Active Plugins'] = 'Aktiveer Invoegsels';
$lang['Active Themes'] = 'Aktiveer Temas';
$lang['... or '] = '... of';
$lang['Add'] = 'Voeg by';
$lang['Add a criteria'] = 'Voeg kriteria by';
$lang['Add a filter'] = 'Voeg filter by';
$lang['Add a tag'] = 'Voeg sleutelwoord by';
$lang['Add a user'] = 'Voeg gebruiker by';
$lang['Add a virtual album'] = 'Voeg virtuele album by';
$lang['Add another set of photos'] = 'Voeg nog \'n stel fotos by';
$lang['Add group'] = 'Voeg groep by';
$lang['Add New Language'] = 'Voeg Nuwe Taal by';
$lang['add new photos to caddie'] = 'plaas nuwe fotos in mandjie';
$lang['Add New Theme'] = 'Voeg Nuwe Tema by';
$lang['Add Photos'] = 'Voeg fotos by';
$lang['Add/delete a permalink'] = 'Voeg by/verwyder permanente skakel';
$lang['added'] = 'bygevoeg';
$lang['Album "%s" has been added'] = 'Album "%s" is bygevoeg';
$lang['Album "%s" now contains %d photos'] = 'Album "%s" bevat nou %d fotos';
$lang['Album name'] = 'Album naam';
$lang['Album updated successfully'] = 'Album opdatering suksesvol';
$lang['all'] = 'alles';
$lang['an error happened'] = '\'n fout het voorgekom';
$lang['An error occured during extraction (%s).'] = '\'n fout het voorgekom met ontbondeling (%s).';
$lang['and'] = 'en';
$lang['Anomaly'] = 'Anomalie';
$lang['Create'] = 'Skep';
$lang['Crop'] = 'Snoei';
$lang['GD version'] = 'GD weergawe';
$lang['General statistics'] = 'Algemene statistiek';
$lang['Get Support on Piwigo Forum'] = 'Kry hulp op die Piwigo Forum';
$lang['Go to'] = 'Gaan na';
$lang['Group name'] = 'Groep naam';
$lang['Groups'] = 'Groepe';
$lang['guest'] = 'gas';
$lang['Guest cannot be deleted'] = 'Gaste kan nie verwyder word nie';
$lang['Guest Settings'] = 'Gas Instellings';
$lang['Guests'] = 'Gaste';
$lang['Height'] = 'Hoogte';
$lang['height must be a number superior to'] = 'hoogte moet \'n getal groter wees as';
$lang['Hello'] = 'Hallo';
$lang['Hello,'] = 'Hallo,';
$lang['Help Me'] = 'Help My';
$lang['Hide'] = 'Versteek';
$lang['high'] = 'hoog';
$lang['High definition'] = 'Hoë definisie';
$lang['History'] = 'Geskiedenis';
$lang['Hour'] = 'Uur';
$lang['Ignore All'] = 'Ignoreer Almal';
$lang['Image id'] = 'Beeld id';
$lang['Image Quality'] = 'Beeld kwaliteit';
$lang['Inactive Languages'] = 'Onaktiewe Tale';
$lang['Inactive Plugins'] = 'Onaktiewe Byvoegsels';
$lang['Inactive Themes'] = 'Onaktiewe Temas';
$lang['Install'] = 'Installeer';
$lang['Install on your computer,'] = 'Installeer op jou rekenaar,';
$lang['Installed Languages'] = 'Geïnstalleerde Tale';
$lang['Installed Themes'] = 'Geïnstalleerde Temas';
$lang['Instructions to use Piwigo'] = 'Instruksies in die gebruik van Piwigo';
$lang['IP'] = 'IP';
$lang['jump to album'] = 'spring na album';
$lang['jump to photo'] = 'spring na foto';
$lang['Languages'] = 'Tale';
$lang['last import'] = 'Laaste invoer';
$lang['Last revisions'] = 'Laaste wysigings';
$lang['Last send'] = 'Laaste stuur';
$lang['leave'] = 'verlaat';
$lang['Level 0'] = 'Vlak 0';
$lang['Level 1'] = 'Vlak 1';
$lang['Level 2'] = 'Vlak 2';
$lang['Level 4'] = 'Vlak 4';
$lang['Level 8'] = 'Vlak 8';
$lang['Main'] = 'Hoof';
$lang['Main Page'] = 'Hoofblad';
$lang['Width'] = 'Wydte';
$lang['Caddie'] = 'Mandjie';
$lang['%s photos can not be regenerated'] = '%s fotos kan nie herskep word nie';
$lang['%s photos have been regenerated'] = '%s fotos is herskep';
$lang['%s thumbnails can not be regenerated'] = '%s duimnaels kan nie herskep word nie';
$lang['%s thumbnails have been regenerated'] = '%s duimnaels is herskep';
$lang['(this tag will be deleted)'] = '(hierdie sleutel gaan verwyder word)';
$lang['Add detailed content'] = 'Voeg detail inhoud by';
$lang['Add write access to the "%s" directory'] = 'Voeg skryfregte by die "%s" gids';
$lang['Administration Home'] = 'Administrasie Tuiste';
$lang['Advanced features'] = 'Gevorderde kenmerke';
$lang['Album list management'] = 'Album lys bestuur';
$lang['Album manual order was saved'] = 'Album handroliese rangskikking is gebêre';
$lang['Album photos associated to the following albums: %s'] = 'Album fotos geassosieer met die volgende albums: %s';
$lang['albums added in the database'] = 'albums bygevoeg tot die databasis';
$lang['Albums authorized thanks to group associations'] = 'Albums bevestig aan die hand van groep verbintenis';
$lang['Albums automatically sorted'] = 'Albums outomaties gesorteer';
$lang['albums deleted in the database'] = 'albums verwyder uit databasis';
?>
